@@ -15,7 +15,7 @@ class UpdateableMiddleware(object):
             for id, hash in zip(ids, hashes):
                 hashvals[id] = hash
         updateable_dict = {
-            'updateable': bool(request.GET.get('update')),
+            'updateable': updateable,
             'hashes': hashvals,
             'contents': [],
         }
@@ -25,11 +25,12 @@ class UpdateableMiddleware(object):
         updateable_dict = getattr(request, settings.UPDATEABLE_REQUEST_OBJECT)
         if updateable_dict['updateable']:
             contents = updateable_dict['contents']
-            content = '<div>%s</div>' % u''.join(contents)
+            content = ''.join(contents)
             response['Content-length'] = str(len(content))
             if getattr(response, 'streaming', False):
                 response.streaming_response = (content,)
             else:
                 response.content = content
+            response['Cache-control'] = 'no-cache' # Preventing IE bug
         return response
 
